@@ -1,38 +1,38 @@
 # BEGIN BPS TAGGED BLOCK {{{
-# 
+#
 # COPYRIGHT:
-#  
-# This software is Copyright (c) 1996-2008 Best Practical Solutions, LLC 
+#
+# This software is Copyright (c) 1996-2008 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
-# 
+#
 # (Except where explicitly superseded by other copyright notices)
-# 
-# 
+#
+#
 # LICENSE:
-# 
+#
 # This work is made available to you under the terms of Version 2 of
 # the GNU General Public License. A copy of that license should have
 # been provided with this software, but in any event can be snarfed
 # from www.gnu.org.
-# 
+#
 # This work is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-# 
-# 
+#
+#
 # CONTRIBUTION SUBMISSION POLICY:
-# 
+#
 # (The following paragraph is not intended to limit the rights granted
 # to you to modify and distribute this software under the terms of
 # the GNU General Public License and is only of importance to you if
 # you choose to contribute your changes and enhancements to the
 # community by submitting them to Best Practical Solutions, LLC.)
-# 
+#
 # By intentionally submitting any modifications, corrections or
 # derivatives to this work, or any other work intended for use with
 # Request Tracker, to Best Practical Solutions, LLC, you confirm that
@@ -41,7 +41,7 @@
 # royalty-free, perpetual, license to use, copy, create derivative
 # works based on those contributions, and sublicense and distribute
 # those contributions and any derivatives thereof.
-# 
+#
 # END BPS TAGGED BLOCK }}}
 use 5.008003;
 use strict;
@@ -49,7 +49,7 @@ use warnings; no warnings qw(redefine);
 
 package RT::Extension::MergeUsers;
 
-our $VERSION = '0.12_02';
+our $VERSION = '0.12_03';
 
 =head1 NAME
 
@@ -57,7 +57,7 @@ RT::Extension::MergeUsers - Merges two users into the same effective user
 
 =head1 DESCRIPTION
 
-This RT extension adds a "Merge Users" box to the User Administration page, 
+This RT extension adds a "Merge Users" box to the User Administration page,
 which allows you to merge the user you are currently viewing with another
 user on your RT instance.
 
@@ -84,7 +84,7 @@ For RT 3.8
     Add RT::Extension::MergeUsers to your /opt/rt3/etc/RT_SiteConfig.pm file
     Set(@Plugins, qw(RT::Extension::MergeUsers));
 
-    If you have more than one Plugin enabled, you must enable them as one 
+    If you have more than one Plugin enabled, you must enable them as one
     Set(@Plugins, qw(Foo Bar)); command
 
 =head1 UPGRADING
@@ -166,10 +166,10 @@ sub LoadOriginal {
 
 sub GetMergedUsers {
     my $self = shift;
-    
+
     my $merged_users = $self->FirstAttribute('MergedUsers');
     unless ($merged_users) {
-        $self->SetAttribute( 
+        $self->SetAttribute(
             Name => 'MergedUsers',
             Description => 'Users that have been merged into this user',
             Content => [] );
@@ -317,19 +317,19 @@ This custom iterator makes sure that duplicate users are never shown in search r
 
 sub Next {
     my $self = shift;
-    
+
     my $user = $self->SUPER::Next(@_);
     unless ($user and $user->id) {
         $self->{seen_users} = undef;
         return undef;
-    }   
-    
-       
+    }
+
+
 
     my ($effective_id) = $user->Attributes->Named("EffectiveId");
     if ($effective_id && $effective_id->Content && $effective_id->Content != $user->id) {
         $user->LoadByCols(id =>$effective_id->Content);
-    }   
+    }
     return $self->Next() if ($self->{seen_users}->{$user->id}++);
 
     return $user;
@@ -341,6 +341,28 @@ sub GotoFirstItem {
     $self->GotoItem(0);
 }
 
+
+package RT::Principal;
+
+sub SetDisabled {
+    my $self = shift;
+    my $value = shift;
+
+    my ($ret, $msg) = $self->_Set( Field => "Disabled", Value => $value );
+    return ($ret, $msg) unless $ret;
+
+    return ($ret, $msg) unless $self->IsUser;
+
+    for my $id (@{$self->Object->GetMergedUsers->Content}) {
+        my $user = RT::User->new( $self->CurrentUser );
+        $user->LoadOriginal( id => $id );
+        $user->PrincipalObj->_Set( Field => "Disabled", Value => $value );
+    }
+
+    return ($ret, $msg);
+}
+
+
 =head1 AUTHOR
 
 Alex Vandiver E<lt>alexmv@bestpractical.comE<gt>
